=========
Cantal-Py
=========

:Status: Beta
:Documentation: http://cantal-py.readthedocs.org/
:Parent Project: git://github.com/tailhook/cantal

Cantal is an expermimental heartbeating, monitoring and statistics solution.
This is a python library for sending statistics data to cantal.

